@@ -67,6 +67,7 @@ File_Aac::File_Aac()
     Frame_Count_Valid=0;
     FrameIsAlwaysComplete=false;
     Mode=Mode_Unknown;
+    FromIamf=false;
     
     //Conformance
     #if MEDIAINFO_CONFORMANCE
@@ -126,6 +127,7 @@ void File_Aac::Streams_Accept()
          case Mode_ADTS :
                        if (!IsSub)
                             TestContinuousFileNames();
+                       break;
         default : ;
     }
     if (Frame_Count_NotParsedIncluded==(int64u)-1)
