@@ -34,16 +34,22 @@ class File_Adm : public File__Analyze
 public :
     //In
     string MuxingMode;
+    float Container_Duration = {};
+    int64u TotalSize = 0;
     void chna_Add(int32u Index, const string& TrackUID);
     void* chna_Move();
     void chna_Move(File_Adm*);
 
+    //Out
+    bool NeedToJumpToEnd = false;
+
     //Constructor/Destructor
     File_Adm();
     ~File_Adm();
 
 private :
     //Streams management
+    void Streams_Accept();
     void Streams_Fill();
 
     //Buffer - File header
