@@ -46,6 +46,8 @@ enum generic
     Generic_Codec_Info,
     Generic_Codec_Url,
     Generic_Codec_CC,
+    Generic_Width,
+    Generic_Height,
     Generic_Duration,
     Generic_Duration_String,
     Generic_Duration_String1,
@@ -460,6 +462,16 @@ enum general
     General_Encoded_Library_Date,
     General_Encoded_Library_Settings,
     General_Encoded_OperatingSystem,
+    General_Encoded_OperatingSystem_String,
+    General_Encoded_OperatingSystem_CompanyName,
+    General_Encoded_OperatingSystem_Name,
+    General_Encoded_OperatingSystem_Version,
+    General_Encoded_Hardware,
+    General_Encoded_Hardware_String,
+    General_Encoded_Hardware_CompanyName,
+    General_Encoded_Hardware_Name,
+    General_Encoded_Hardware_Model,
+    General_Encoded_Hardware_Version,
     General_Cropped,
     General_Dimensions,
     General_DotsPerInch,
@@ -1501,6 +1513,7 @@ enum text
     Text_Events_PaintOn,
     Text_Lines_Count,
     Text_Lines_MaxCountPerEvent,
+    Text_Lines_MaxCharacterCount,
     Text_FirstDisplay_Delay_Frames,
     Text_FirstDisplay_Type,
 };
@@ -1537,8 +1550,10 @@ enum other
     Other_Format_Profile,
     Other_Format_Compression,
     Other_Format_Settings,
+    Other_Format_Settings_Wrapping,
     Other_Format_AdditionalFeatures,
     Other_MuxingMode,
+    Other_MuxingMode_MoreInfo,
     Other_CodecID,
     Other_CodecID_String,
     Other_CodecID_Info,
@@ -1745,6 +1760,7 @@ enum image
     Image_Format_Settings_Endianness,
     Image_Format_Settings_Packing,
     Image_Format_Settings_Wrapping,
+    Image_MuxingMode,
     Image_InternetMediaType,
     Image_CodecID,
     Image_CodecID_String,
