@@ -40,6 +40,21 @@ template <class T> inline Ztring Get_Hex_ID(const T& Value)
     return ID_String;
 }
 
+template <class T> inline T IsAsciiLower(T Value)
+{
+    return ((unsigned)Value - 'a') < 26;
+}
+
+template <class T> inline T IsAsciiUpper(T Value)
+{
+    return ((unsigned)Value - 'A') < 26;
+}
+
+template <class T> inline T IsAsciiDigit(T Value)
+{
+    return ((unsigned)Value - '0') < 10;
+}
+
 struct buffer_data
 {
     size_t Size;
@@ -879,6 +894,7 @@ public :
     #define Info_UTF8(_BYTES, _INFO, _NAME)   Ztring _INFO; Get_UTF8  (_BYTES, _INFO, _NAME)
     #define Info_UTF16B(_BYTES, _INFO, _NAME) Ztring _INFO; Get_UTF16B(_BYTES, _INFO, _NAME)
     #define Info_UTF16L(_BYTES, _INFO, _NAME) Ztring _INFO; Get_UTF16L(_BYTES, _INFO, _NAME)
+    size_t SizeUpTo0(size_t Size=(size_t)-1);
 
     //***************************************************************************
     // PAscal strings
