@@ -1449,6 +1449,17 @@ void File__Analyze::Get_UTF16L(int64u Bytes, Ztring &Info)
     Element_Offset+=Bytes;
 }
 
+//---------------------------------------------------------------------------
+size_t File__Analyze::SizeUpTo0(size_t MaxSize)
+{
+    auto Buffer_Begin=Buffer+Buffer_Offset+(size_t)Element_Offset;
+    auto Buffer_Current=Buffer_Begin;
+    auto Buffer_End=Buffer+Buffer_Offset+(MaxSize>((size_t)Element_Size)?((size_t)Element_Size):MaxSize);
+    while (Buffer_Current<Buffer_End && *Buffer_Current)
+        Buffer_Current++;
+    return Buffer_Current-Buffer_Begin;
+}
+
 //***************************************************************************
 // Text
 //***************************************************************************
