@@ -149,6 +149,9 @@
 #if defined(MEDIAINFO_AVSV_YES)
     #include "MediaInfo/Video/File_AvsV.h"
 #endif
+#if defined(MEDIAINFO_AVS3V_YES)
+    #include "MediaInfo/Video/File_Avs3V.h"
+#endif
 #if defined(MEDIAINFO_DIRAC_YES)
     #include "MediaInfo/Video/File_Dirac.h"
 #endif
@@ -158,6 +161,9 @@
 #if defined(MEDIAINFO_H263_YES)
     #include "MediaInfo/Video/File_H263.h"
 #endif
+#if defined(MEDIAINFO_MXF_YES)
+    #include "MediaInfo/Video/File_HdrVividMetadata.h"
+#endif
 #if defined(MEDIAINFO_HEVC_YES)
     #include "MediaInfo/Video/File_Hevc.h"
 #endif
@@ -233,6 +239,9 @@
 #if defined(MEDIAINFO_FLAC_YES)
     #include "MediaInfo/Audio/File_Flac.h"
 #endif
+#if defined(MEDIAINFO_IAMF_YES)
+    #include "MediaInfo/Audio/File_Iamf.h"
+#endif
 #if defined(MEDIAINFO_IT_YES)
     #include "MediaInfo/Audio/File_ImpulseTracker.h"
 #endif
@@ -290,6 +299,9 @@
 #if defined(MEDIAINFO_N19_YES)
     #include "MediaInfo/Text/File_N19.h"
 #endif
+#if defined(MEDIAINFO_PAC_YES)
+    #include "MediaInfo/Text/File_Pac.h"
+#endif
 #if defined(MEDIAINFO_PDF_YES)
     #include "MediaInfo/Text/File_Pdf.h"
 #endif
@@ -356,6 +368,12 @@
 #if defined(MEDIAINFO_ICC_YES)
     #include "MediaInfo/Tag/File_Icc.h"
 #endif
+#if defined(MEDIAINFO_SPHERICALVIDEO_YES)
+    #include "MediaInfo/Tag/File_SphericalVideo.h"
+#endif
+#if defined(MEDIAINFO_XMP_YES)
+    #include "MediaInfo/Tag/File_Xmp.h"
+#endif
 
 //---------------------------------------------------------------------------
 // Archive
@@ -562,6 +580,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_AVC_YES)
         Parser.push_back(new File_Avc());
     #endif
+    #if defined(MEDIAINFO_MXF_YES)
+        Parser.push_back(new File_HdrVividMetadata());
+    #endif
     #if defined(MEDIAINFO_HEVC_YES)
         Parser.push_back(new File_Hevc());
     #endif
@@ -701,6 +722,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_N19_YES)
         Parser.push_back(new File_N19());
     #endif
+    #if defined(MEDIAINFO_PAC_YES)
+        Parser.push_back(new File_Pac());
+    #endif
     #if defined(MEDIAINFO_PDF_YES)
         Parser.push_back(new File_Pdf());
     #endif
@@ -758,6 +782,14 @@ File__MultipleParsing::File__MultipleParsing()
         Parser.push_back(new File_Tiff());
     #endif
 
+    // Tag
+    #if defined(MEDIAINFO_SPHERICALVIDEO_YES)
+        Parser.push_back(new File_SphericalVideo());
+    #endif
+    #if defined(MEDIAINFO_XMP_YES)
+        Parser.push_back(new File_Xmp());
+    #endif
+
     // Archive
     #if defined(MEDIAINFO_7Z_YES)
         Parser.push_back(new File_7z());
