@@ -281,6 +281,7 @@ File_DvDif::File_DvDif()
     AbstBf_Previous_MaxAbst=0xFFFFFF;
     SMP=(int8u)-1;
     QU=(int8u)-1;
+    REC_IsValid=false;
     Speed_TimeCode_IsValid=false;
     Speed_Arb_IsValid=false;
     Mpeg4_stts=NULL;
@@ -395,6 +396,7 @@ void File_DvDif::Streams_Fill()
                         case 7 : Fill(Stream_Video, 0, Video_DisplayAspectRatio, 4.0/3.0, 3, true); break;
                         default: ; //No indication of aspect ratio?
                      }
+                     break;
             default: ;
         }
     }
@@ -934,7 +936,7 @@ size_t File_DvDif::Read_Buffer_Seek (size_t Method, int64u Value, int64u /*ID*/)
                         //We transform TimeStamp to a frame number
                         Value=float64_int64s(((float64)Value)*(DSF?25.000:(30.000*1000/1001))/1000000000);
                     }
-                    //No break;
+                    [[fallthrough]];
         case 3  :   //FrameNumber
                     if (!FSP_WasNotSet)
                     {
