@@ -217,7 +217,7 @@ private :
     void moov_trak_mdia_minf_stbl_stsd_xxxxSound();
     void moov_trak_mdia_minf_stbl_stsd_xxxxText();
     void moov_trak_mdia_minf_stbl_stsd_xxxxVideo();
-    void moov_trak_mdia_minf_stbl_stsd_xxxxOthers();
+    void moov_trak_mdia_minf_stbl_stsd_xxxxOthers(const string& CodecIDAddition);
     void moov_trak_mdia_minf_stbl_stsd_xxxx_alac();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_AALP();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_ACLR();
@@ -260,6 +260,7 @@ private :
     void moov_trak_mdia_minf_stbl_stsd_xxxx_jp2h() {jp2h();}
     void moov_trak_mdia_minf_stbl_stsd_xxxx_jp2h_colr() {jp2h_colr();}
     void moov_trak_mdia_minf_stbl_stsd_xxxx_jp2h_ihdr() {jp2h_ihdr();}
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_iacb();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_lhvC();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_mdcv();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_mhaC();
@@ -330,6 +331,8 @@ private :
     void moov_trak_udta_free() { moov_udta_free(); }
     void moov_trak_udta_Xtra() { moov_udta_Xtra(); }
     void moov_trak_udta_xxxx();
+    void moov_trak_uuid();
+    void moov_trak_uuid_SphericalVideo();
     void moov_udta();
     void moov_udta_AllF();
     void moov_udta_chpl();
@@ -370,6 +373,8 @@ private :
     void moov_udta_rtng();
     void moov_udta_ptv ();
     void moov_udta_Sel0();
+    void moov_udta_smta();
+    void moov_udta_smta_mdln();
     void moov_udta_tags();
     void moov_udta_tags_meta();
     void moov_udta_tags_tseg();
@@ -417,8 +422,16 @@ private :
     void Descriptors();
     void TimeCode_Associate(int32u TrackID);
     void AddCodecConfigurationBoxInfo();
+    void Loop_CheckValue(int32u& Value, int64u RemainingSize, int8u MinBlockSize, const char* Name);
+    void Loop_CheckValue(int32u& Value, int8u MinBlockSize, const char* Name);
+    void Loop_CheckValue(int16u& Value, int8u MinBlockSize, const char* Name) { int32u Value2 = Value; Loop_CheckValue(Value2, MinBlockSize, Name); Value = Value2; }
+    void Loop_CheckValue(int8u& Value, int8u MinBlockSize, const char* Name) { int32u Value2 = Value; Loop_CheckValue(Value2, MinBlockSize, Name); Value = Value2; }
+    void Loop_CheckValue_BS(int32u& Value, int8u MinBlockSize, const char* Name);
+    void Loop_CheckValue_BS(int16u& Value, int8u MinBlockSize, const char* Name) { int32u Value2 = Value; Loop_CheckValue_BS(Value2, MinBlockSize, Name); Value = Value2; }
+    void Loop_CheckValue_BS(int8u& Value, int8u MinBlockSize, const char* Name) { int32u Value2 = Value; Loop_CheckValue_BS(Value2, MinBlockSize, Name); Value = Value2; }
 
     //Temp
+    int128u                                 Name_UUID;
     bool List;
     bool                                    mdat_MustParse;
     int32u                                  moov_cmov_dcom_Compressor;
@@ -490,6 +503,15 @@ private :
             bool   NegativeTimes;
         };
         timecode* TimeCode;
+        struct nclc
+        {
+            int8u  colour_primaries;
+            int8u  transfer_characteristics;
+            int8u  matrix_coefficients;
+            bool   HasFlags;
+            bool   full_range_flag;
+        };
+        nclc* Nclc;
         stream_t                StreamKind;
         size_t                  StreamPos;
         int32u                  hdlr_Type;
@@ -551,6 +573,7 @@ private :
         bool                    AllForcedSamples;
         bool                    IsImage;
         bool                    IsCaption;
+        bool                    MayHaveCaption;
         bool                    tkhd_Found;
         int32u                  TrackID;
         std::vector<mdat_Pos_Type> mdat_Pos;
@@ -607,6 +630,7 @@ private :
         {
             MI=NULL;
             TimeCode=NULL;
+            Nclc=NULL;
             StreamKind=Stream_Max;
             StreamPos=(size_t)-1;
             hdlr_Type=0x00000000;
@@ -649,6 +673,7 @@ private :
             AllForcedSamples=false;
             IsImage=false;
             IsCaption=false;
+            MayHaveCaption=false;
             tkhd_Found=false;
             CleanAperture_Width=0;
             CleanAperture_Height=0;
@@ -678,6 +703,7 @@ private :
                 delete Parsers[Pos];
             delete MI; //MI=NULL;
             delete TimeCode; //TimeCode=NULL;
+            delete Nclc; //Nclc=NULL;
         }
 
         void Parsers_Clear()
