@@ -17,7 +17,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#if defined(MEDIAINFO_PDF_YES) || defined(MEDIAINFO_PNG_YES)
+#if defined(MEDIAINFO_XMP_YES)
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -130,6 +130,12 @@ bool File_Xmp::FileHeader_Begin()
 
                 Fill(Stream_General, 0, General_Format_Profile, Profile);
             }
+            const char* Credit = Rdf_Item->Attribute("photoshop:Credit");
+            if (Credit && *Credit != '\\') //TODO: support octal and UTF-16 ("\376\377")
+                Fill(Stream_General, 0, General_Copyright, Credit);
+            const char* CreatorTool=Rdf_Item->Attribute("xmp:CreatorTool");
+            if (CreatorTool && *CreatorTool!='\\') //TODO: support octal and UTF-16 ("\376\377")
+                Fill(Stream_General, 0, General_Encoded_Application, CreatorTool);
             Ztring ModifyDate, CreateDate;
             for (XMLElement* Description_Item = Rdf_Item->FirstChildElement(); Description_Item; Description_Item=Description_Item->NextSiblingElement())
             {
@@ -157,4 +163,4 @@ bool File_Xmp::FileHeader_Begin()
 
 } //NameSpace
 
-#endif //MEDIAINFO_PDF_YES
+#endif //MEDIAINFO_XMP_YES
