@@ -217,7 +217,7 @@ void File_Ttml::Streams_Finish()
         if (!Time_End.IsTimed() && Time_End>Time_Begin)
         {
             TimeCode LastFrame=Time_End;
-            LastFrame--;
+            --LastFrame;
             Fill(Stream_Text, 0, Text_TimeCode_LastFrame, LastFrame.ToString());
         }
         auto MediaTimeToMilliseconds=[&](TimeCode TC)
@@ -440,7 +440,7 @@ void File_Ttml::Read_Buffer_Continue()
         Fill(Stream_General, 0, General_Format_Profile, "IMSC1");
         Fill(Stream_Text, 0, Text_Format_Profile, "IMSC1");
     }
-    
+    string Rosetta_Profile, Rosetta_Version;
 
     tinyxml2::XMLElement*       div=NULL;
     #if MEDIAINFO_EVENTS
@@ -660,12 +660,35 @@ void File_Ttml::Read_Buffer_Continue()
                                     Fill(Stream_Text, 0, "CaptionServiceName", Attribute);
                             }
                         }
+                        if (!strcmp(metadata_element->Value(), "rosetta:format"))
+                        {
+                            for (auto format_element = metadata_element->FirstChild(); format_element; format_element = format_element->NextSiblingElement())
+                            {
+                                Rosetta_Profile = format_element->Value();
+                                break;
+                            }
+                        }
+                        if (!strcmp(metadata_element->Value(), "rosetta:version"))
+                        {
+                            for (auto format_element = metadata_element->FirstChild(); format_element; format_element = format_element->NextSiblingElement())
+                            {
+                                Rosetta_Version = format_element->Value();
+                                break;
+                            }
+                        }
                     }
                 }
             }
         }
     }
 
+    if (!Rosetta_Profile.empty())
+    {
+        auto Profile = Rosetta_Profile + (Rosetta_Version.empty() ? string() : (' ' + Rosetta_Version));
+        Fill(Stream_General, 0, General_Format_Profile, Profile);
+        Fill(Stream_Text, 0, Text_Format_Profile, Profile);
+    }
+
     #if MEDIAINFO_DEMUX
         Demux(Buffer, Buffer_Size, ContentType_MainStream);
     #endif //MEDIAINFO_DEMUX
@@ -736,10 +759,11 @@ void File_Ttml::Read_Buffer_Continue()
                     Content.FindAndReplace(__T("<br/>"), EOL, 0, ZenLib::Ztring_Recursive);
                     Content.FindAndReplace(__T("<br />"), EOL, 0, ZenLib::Ztring_Recursive);
 
+                    std::wstring Content_Unicode{ Content.To_Unicode() };
                     Event.DTS=DTS_Begin;
                     Event.PTS=Event.DTS;
                     Event.DUR=DTS_End-DTS_Begin;
-                    Event.Content=Content.To_Unicode().c_str();
+                    Event.Content=Content_Unicode.c_str();
                     Event.Flags=0;
                     Event.MuxingMode=MuxingMode;
                     Event.Service=(int8u)Element_Code;
